@@ -146,6 +146,15 @@ typedef struct
   int new_index;
 } LayerChangeType;
 
+/*!
+ * \brief Information about layer changes.
+ */
+typedef struct
+{
+  int from;
+  int to;
+} SetViaLayersChangeType;
+
 /*!
  * \brief Information about poly clear/restore.
  */
@@ -186,6 +195,7 @@ typedef struct
     LayerChangeType LayerChange;
     ClearPolyType ClearPoly;
     NetlistChangeType NetlistChange;
+    SetViaLayersChangeType SetViaLayersChange;
     long int CopyID;
   }
   Data;
@@ -229,6 +239,7 @@ static bool UndoChangeAngles (UndoListType *);
 static bool UndoChangeClearSize (UndoListType *);
 static bool UndoChangeMaskSize (UndoListType *);
 static bool UndoClearPoly (UndoListType *);
+static bool UndoSetViaLayers (UndoListType *);
 static int PerformUndo (UndoListType *);
 
 /*!
@@ -1021,8 +1032,40 @@ UndoNetlistChange (UndoListType *Entry)
   return true;
 }
 
-/*!
- * \brief Undo of any 'hard to recover' operation.
+/* ---------------------------------------------------------------------------
+ * recovers an object from a Size change operation
+ */
+static bool
+UndoSetViaLayers (UndoListType *Entry)
+{
+  void *ptr1, *ptr2, *ptr3;
+  int type;
+  int from, to;
+
+  /* lookup entry by ID */
+  type =
+    SearchObjectByID (PCB->Data, &ptr1, &ptr2, &ptr3, Entry->ID, Entry->Kind);
+  if (type == VIA_TYPE)
+    {
+      from = ((PinType *) ptr2)->BuriedFrom;
+      to = ((PinType *) ptr2)->BuriedTo;
+      RestoreToPolygon (PCB->Data, type, ptr1, ptr2);
+      if (andDraw)
+	EraseObject (type, ptr1, ptr2);
+      ((PinType *) ptr2)->BuriedFrom = Entry->Data.SetViaLayersChange.from;
+      ((PinType *) ptr2)->BuriedTo = Entry->Data.SetViaLayersChange.to;
+      Entry->Data.SetViaLayersChange.from = from;
+      Entry->Data.SetViaLayersChange.to = to;
+      ClearFromPolygon (PCB->Data, type, ptr1, ptr2);
+      if (andDraw)
+	DrawObject (type, ptr1, ptr2);
+      return (true);
+    }
+  return (false);
+}
+
+/* ---------------------------------------------------------------------------
+ * \brief Undo of any 'hard to recover' operation
  *
  * \return The bitfield for the types of operations that were undone.
  */
@@ -1203,6 +1246,11 @@ PerformUndo (UndoListType *ptr)
       if (UndoMirror (ptr))
 	return (UNDO_MIRROR);
       break;
+
+    case UNDO_CHANGESETVIALAYERS:
+      if (UndoSetViaLayers (ptr))
+        return (UNDO_CHANGESETVIALAYERS);
+      break;
     }
   return 0;
 }
@@ -1824,8 +1872,25 @@ AddNetlistLibToUndoList (LibraryType *lib)
     }
 }
 
-/*!
- * \brief Set lock flag.
+/* ---------------------------------------------------------------------------
+ * adds an object to the list of objects with buried info data
+ */
+void
+AddObjectToSetViaLayersUndoList (void *ptr1, void *ptr2, void *ptr3)
+{
+  UndoListType *undo;
+
+  if (!Locked)
+    {
+      undo = GetUndoSlot (UNDO_CHANGESETVIALAYERS, OBJECT_ID (ptr2), VIA_TYPE);
+      undo->Data.SetViaLayersChange.from = ((PinType *) ptr2)->BuriedFrom;
+      undo->Data.SetViaLayersChange.to = ((PinType *) ptr2)->BuriedTo;
+    }
+}
+
+
+/* ---------------------------------------------------------------------------
+ * \brief Set lock flag
  */
 void
 LockUndo (void)
